# pydiscovergy [![Build Status](https://travis-ci.org/jpbede/pydiscovergy.svg?branch=master)](https://travis-ci.org/jpbede/pydiscovergy)
Python library for discovergy smart meters


Install
=======

`pip install pydiscovergy`